pub struct StringType {}Trait Implementations
Sourceimpl ChunkExpandAtIndex<StringType> for StringChunked
impl ChunkExpandAtIndex<StringType> for StringChunked
Sourcefn new_from_index(&self, index: usize, length: usize) -> StringChunked
fn new_from_index(&self, index: usize, length: usize) -> StringChunked
Create a new ChunkedArray filled with values at that index.
Sourceimpl ChunkSort<StringType> for StringChunked
impl ChunkSort<StringType> for StringChunked
Sourcefn arg_sort_multiple(
&self,
by: &[Column],
options: &SortMultipleOptions,
) -> PolarsResult<IdxCa>
fn arg_sort_multiple( &self, by: &[Column], options: &SortMultipleOptions, ) -> PolarsResult<IdxCa>
Panics
This function is very opinionated. On the implementation of ChunkedArray<T> for numeric types,
we assume that all numeric Series are of the same type.
In this case we assume that all numeric Series are f64 types. The caller needs to
uphold this contract. If not, it will panic.
fn sort_with(&self, options: SortOptions) -> ChunkedArray<StringType>
Sourcefn sort(&self, descending: bool) -> StringChunked
fn sort(&self, descending: bool) -> StringChunked
Returned a sorted
ChunkedArray.Sourcefn arg_sort(&self, options: SortOptions) -> IdxCa
fn arg_sort(&self, options: SortOptions) -> IdxCa
Retrieve the indexes needed to sort this array.
Sourceimpl Clone for StringType
impl Clone for StringType
Sourcefn clone(&self) -> StringType
fn clone(&self) -> StringType
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<S> NewChunkedArray<StringType, S> for StringChunked
impl<S> NewChunkedArray<StringType, S> for StringChunked
Sourcefn from_iter_values(name: PlSmallStr, it: impl Iterator<Item = S>) -> Self
fn from_iter_values(name: PlSmallStr, it: impl Iterator<Item = S>) -> Self
Create a new ChunkedArray from an iterator.
fn from_slice(name: PlSmallStr, v: &[S]) -> Self
fn from_slice_options(name: PlSmallStr, opt_v: &[Option<S>]) -> Self
Sourcefn from_iter_options(
name: PlSmallStr,
it: impl Iterator<Item = Option<S>>,
) -> Self
fn from_iter_options( name: PlSmallStr, it: impl Iterator<Item = Option<S>>, ) -> Self
Create a new ChunkedArray from an iterator.
Sourceimpl NumOpsDispatchInner for StringType
impl NumOpsDispatchInner for StringType
fn add_to(lhs: &StringChunked, rhs: &Series) -> PolarsResult<Series>
fn subtract(lhs: &ChunkedArray<Self>, rhs: &Series) -> PolarsResult<Series>
fn multiply(lhs: &ChunkedArray<Self>, rhs: &Series) -> PolarsResult<Series>
fn divide(lhs: &ChunkedArray<Self>, rhs: &Series) -> PolarsResult<Series>
fn remainder(lhs: &ChunkedArray<Self>, rhs: &Series) -> PolarsResult<Series>
Sourceimpl PolarsDataType for StringType
impl PolarsDataType for StringType
type Physical<'a> = &'a str
type OwnedPhysical = String
type ZeroablePhysical<'a> = Option<&'a str>
type Array = BinaryViewArrayGeneric<str>
type IsNested = FalseT
type HasViews = TrueT
type IsStruct = FalseT
type IsObject = FalseT
Sourcefn get_static_dtype() -> DataType
fn get_static_dtype() -> DataType
Returns the DataType variant associated with this PolarsDataType.
Not implemented for types whose DataTypes have parameters.
Sourceimpl PolarsPhysicalType for StringType
impl PolarsPhysicalType for StringType
fn ca_into_series(ca: ChunkedArray<Self>) -> Series
impl Copy for StringType