pub type BinaryOffsetChunked = ChunkedArray<BinaryOffsetType>;Aliased Type
pub struct BinaryOffsetChunked { /* private fields */ }Trait Implementations
Sourceimpl ChunkAnyValue for BinaryOffsetChunked
impl ChunkAnyValue for BinaryOffsetChunked
Sourceunsafe fn get_any_value_unchecked(&self, index: usize) -> AnyValue<'_>
unsafe fn get_any_value_unchecked(&self, index: usize) -> AnyValue<'_>
Get a single value. Beware this is slow.
If you need to use this slightly performant, cast Categorical to UInt32 Read more
Sourcefn get_any_value(&self, index: usize) -> PolarsResult<AnyValue<'_>>
fn get_any_value(&self, index: usize) -> PolarsResult<AnyValue<'_>>
Get a single value. Beware this is slow.
Sourceimpl ChunkCast for BinaryOffsetChunked
impl ChunkCast for BinaryOffsetChunked
Sourcefn cast_with_options(
&self,
dtype: &DataType,
options: CastOptions,
) -> PolarsResult<Series>
fn cast_with_options( &self, dtype: &DataType, options: CastOptions, ) -> PolarsResult<Series>
Cast a
ChunkedArray to DataTypeSourceunsafe fn cast_unchecked(&self, dtype: &DataType) -> PolarsResult<Series>
unsafe fn cast_unchecked(&self, dtype: &DataType) -> PolarsResult<Series>
Does not check if the cast is a valid one and may over/underflow Read more
Sourcefn cast(&self, dtype: &DataType) -> PolarsResult<Series>
fn cast(&self, dtype: &DataType) -> PolarsResult<Series>
Cast a
ChunkedArray to DataTypeSourceimpl ChunkCompareEq<&[u8]> for BinaryOffsetChunked
impl ChunkCompareEq<&[u8]> for BinaryOffsetChunked
type Item = ChunkedArray<BooleanType>
Sourcefn equal(&self, rhs: &[u8]) -> BooleanChunked
fn equal(&self, rhs: &[u8]) -> BooleanChunked
Check for equality.
Sourcefn equal_missing(&self, rhs: &[u8]) -> BooleanChunked
fn equal_missing(&self, rhs: &[u8]) -> BooleanChunked
Check for equality where
None == None.Sourcefn not_equal(&self, rhs: &[u8]) -> BooleanChunked
fn not_equal(&self, rhs: &[u8]) -> BooleanChunked
Check for inequality.
Sourcefn not_equal_missing(&self, rhs: &[u8]) -> BooleanChunked
fn not_equal_missing(&self, rhs: &[u8]) -> BooleanChunked
Check for inequality where
None == None.Sourceimpl ChunkCompareEq<&ChunkedArray<BinaryOffsetType>> for BinaryOffsetChunked
impl ChunkCompareEq<&ChunkedArray<BinaryOffsetType>> for BinaryOffsetChunked
type Item = ChunkedArray<BooleanType>
Sourcefn equal(&self, rhs: &BinaryOffsetChunked) -> BooleanChunked
fn equal(&self, rhs: &BinaryOffsetChunked) -> BooleanChunked
Check for equality.
Sourcefn equal_missing(&self, rhs: &BinaryOffsetChunked) -> BooleanChunked
fn equal_missing(&self, rhs: &BinaryOffsetChunked) -> BooleanChunked
Check for equality where
None == None.Sourcefn not_equal(&self, rhs: &BinaryOffsetChunked) -> BooleanChunked
fn not_equal(&self, rhs: &BinaryOffsetChunked) -> BooleanChunked
Check for inequality.
Sourcefn not_equal_missing(&self, rhs: &BinaryOffsetChunked) -> BooleanChunked
fn not_equal_missing(&self, rhs: &BinaryOffsetChunked) -> BooleanChunked
Check for inequality where
None == None.Sourceimpl ChunkCompareIneq<&[u8]> for BinaryOffsetChunked
impl ChunkCompareIneq<&[u8]> for BinaryOffsetChunked
type Item = ChunkedArray<BooleanType>
Sourcefn gt(&self, rhs: &[u8]) -> BooleanChunked
fn gt(&self, rhs: &[u8]) -> BooleanChunked
Greater than comparison.
Sourcefn gt_eq(&self, rhs: &[u8]) -> BooleanChunked
fn gt_eq(&self, rhs: &[u8]) -> BooleanChunked
Greater than or equal comparison.
Sourcefn lt(&self, rhs: &[u8]) -> BooleanChunked
fn lt(&self, rhs: &[u8]) -> BooleanChunked
Less than comparison.
Sourcefn lt_eq(&self, rhs: &[u8]) -> BooleanChunked
fn lt_eq(&self, rhs: &[u8]) -> BooleanChunked
Less than or equal comparison
Sourceimpl ChunkCompareIneq<&ChunkedArray<BinaryOffsetType>> for BinaryOffsetChunked
impl ChunkCompareIneq<&ChunkedArray<BinaryOffsetType>> for BinaryOffsetChunked
type Item = ChunkedArray<BooleanType>
Sourcefn lt(&self, rhs: &BinaryOffsetChunked) -> BooleanChunked
fn lt(&self, rhs: &BinaryOffsetChunked) -> BooleanChunked
Less than comparison.
Sourcefn lt_eq(&self, rhs: &BinaryOffsetChunked) -> BooleanChunked
fn lt_eq(&self, rhs: &BinaryOffsetChunked) -> BooleanChunked
Less than or equal comparison
Sourcefn gt(&self, rhs: &Self) -> BooleanChunked
fn gt(&self, rhs: &Self) -> BooleanChunked
Greater than comparison.
Sourcefn gt_eq(&self, rhs: &Self) -> BooleanChunked
fn gt_eq(&self, rhs: &Self) -> BooleanChunked
Greater than or equal comparison.
Sourceimpl ChunkExpandAtIndex<BinaryOffsetType> for BinaryOffsetChunked
impl ChunkExpandAtIndex<BinaryOffsetType> for BinaryOffsetChunked
Sourcefn new_from_index(&self, index: usize, length: usize) -> BinaryOffsetChunked
fn new_from_index(&self, index: usize, length: usize) -> BinaryOffsetChunked
Create a new ChunkedArray filled with values at that index.
Sourceimpl<'a> ChunkFull<&'a [u8]> for BinaryOffsetChunked
impl<'a> ChunkFull<&'a [u8]> for BinaryOffsetChunked
Sourceimpl ChunkFullNull for BinaryOffsetChunked
impl ChunkFullNull for BinaryOffsetChunked
fn full_null(name: PlSmallStr, length: usize) -> Self
Sourceimpl ChunkReverse for BinaryOffsetChunked
impl ChunkReverse for BinaryOffsetChunked
Sourceimpl ChunkSort<BinaryOffsetType> for BinaryOffsetChunked
impl ChunkSort<BinaryOffsetType> for BinaryOffsetChunked
Sourcefn arg_sort_multiple(
&self,
by: &[Column],
options: &SortMultipleOptions,
) -> PolarsResult<IdxCa>
fn arg_sort_multiple( &self, by: &[Column], options: &SortMultipleOptions, ) -> PolarsResult<IdxCa>
Panics
This function is very opinionated. On the implementation of ChunkedArray<T> for numeric types,
we assume that all numeric Series are of the same type.
In this case we assume that all numeric Series are f64 types. The caller needs to
uphold this contract. If not, it will panic.
fn sort_with(&self, options: SortOptions) -> BinaryOffsetChunked
Sourcefn sort(&self, descending: bool) -> BinaryOffsetChunked
fn sort(&self, descending: bool) -> BinaryOffsetChunked
Returned a sorted
ChunkedArray.Sourcefn arg_sort(&self, options: SortOptions) -> IdxCa
fn arg_sort(&self, options: SortOptions) -> IdxCa
Retrieve the indexes needed to sort this array.
Sourceimpl ChunkUnique for BinaryOffsetChunked
Available on crate feature algorithm_group_by only.
impl ChunkUnique for BinaryOffsetChunked
Available on crate feature
algorithm_group_by only.Sourcefn unique(&self) -> PolarsResult<Self>
fn unique(&self) -> PolarsResult<Self>
Get unique values of a ChunkedArray
Sourcefn arg_unique(&self) -> PolarsResult<IdxCa>
fn arg_unique(&self) -> PolarsResult<IdxCa>
Get first index of the unique values in a
ChunkedArray.
This Vec is sorted.Sourcefn n_unique(&self) -> PolarsResult<usize>
fn n_unique(&self) -> PolarsResult<usize>
Number of unique values in the
ChunkedArraySourceimpl<Ptr> FromTrustedLenIterator<Option<Ptr>> for BinaryOffsetChunked
impl<Ptr> FromTrustedLenIterator<Option<Ptr>> for BinaryOffsetChunked
fn from_iter_trusted_length<I: IntoIterator<Item = Option<Ptr>>>( iter: I, ) -> Self
Sourceimpl<Ptr> FromTrustedLenIterator<Ptr> for BinaryOffsetChunkedwhere
Ptr: PolarsAsRef<[u8]>,
impl<Ptr> FromTrustedLenIterator<Ptr> for BinaryOffsetChunkedwhere
Ptr: PolarsAsRef<[u8]>,
fn from_iter_trusted_length<I: IntoIterator<Item = Ptr>>(iter: I) -> Self
Sourceimpl IntoGroupsType for BinaryOffsetChunked
Available on crate feature algorithm_group_by only.
impl IntoGroupsType for BinaryOffsetChunked
Available on crate feature
algorithm_group_by only.Sourcefn group_tuples<'a>(
&'a self,
multithreaded: bool,
sorted: bool,
) -> PolarsResult<GroupsType>
fn group_tuples<'a>( &'a self, multithreaded: bool, sorted: bool, ) -> PolarsResult<GroupsType>
Create the tuples need for a group_by operation.
* The first value in the tuple is the first index of the group.
* The second value in the tuple is the indexes of the groups including the first value.
Sourceimpl<'a> IntoIterator for &'a BinaryOffsetChunked
impl<'a> IntoIterator for &'a BinaryOffsetChunked
Sourcetype IntoIter = Box<dyn PolarsIterator<Item = <&'a ChunkedArray<BinaryOffsetType> as IntoIterator>::Item> + 'a>
type IntoIter = Box<dyn PolarsIterator<Item = <&'a ChunkedArray<BinaryOffsetType> as IntoIterator>::Item> + 'a>
Which kind of iterator are we turning this into?
Sourceimpl ValueSize for BinaryOffsetChunked
impl ValueSize for BinaryOffsetChunked
Sourcefn get_values_size(&self) -> usize
fn get_values_size(&self) -> usize
Get the values size that is still “visible” to the underlying array.
E.g. take the offsets into account.
Sourceimpl VecHash for BinaryOffsetChunked
impl VecHash for BinaryOffsetChunked
Sourcefn vec_hash(
&self,
random_state: PlSeedableRandomStateQuality,
buf: &mut Vec<u64>,
) -> PolarsResult<()>
fn vec_hash( &self, random_state: PlSeedableRandomStateQuality, buf: &mut Vec<u64>, ) -> PolarsResult<()>
Compute the hash for all values in the array.