Type Alias polars_core::datatypes::BooleanChunked
source · pub type BooleanChunked = ChunkedArray<BooleanType>;Aliased Type
struct BooleanChunked { /* private fields */ }Implementations
sourceimpl BooleanChunked
impl BooleanChunked
Booleans are cast to 1 or 0.
sourceimpl BooleanChunked
impl BooleanChunked
sourcepub fn any(&self) -> bool
pub fn any(&self) -> bool
Returns whether any of the values in the column are true.
Null values are ignored.
sourcepub fn all(&self) -> bool
pub fn all(&self) -> bool
Returns whether all values in the array are true.
Null values are ignored.
sourcepub fn any_kleene(&self) -> Option<bool>
pub fn any_kleene(&self) -> Option<bool>
Returns whether any of the values in the column are true.
The output is unknown (None) if the array contains any null values and
no true values.
sourcepub fn all_kleene(&self) -> Option<bool>
pub fn all_kleene(&self) -> Option<bool>
Returns whether all values in the column are true.
The output is unknown (None) if the array contains any null values and
no false values.
sourceimpl BooleanChunked
impl BooleanChunked
sourcepub unsafe fn mmap_slice(
name: &str,
values: &[u8],
offset: usize,
len: usize
) -> Self
pub unsafe fn mmap_slice( name: &str, values: &[u8], offset: usize, len: usize ) -> Self
Create a temporary ChunkedArray from a slice.
Safety
The lifetime will be bound to the lifetime of the slice. This will not be checked by the borrowchecker.
sourceimpl BooleanChunked
impl BooleanChunked
sourcepub fn rand_bernoulli(name: &str, length: usize, p: f64) -> PolarsResult<Self>
Available on crate feature random only.
pub fn rand_bernoulli(name: &str, length: usize, p: f64) -> PolarsResult<Self>
random only.Create ChunkedArray with samples from a Bernoulli distribution.