pub trait IntoGroupsType {
// Provided method
fn group_tuples(
&self,
_multithreaded: bool,
_sorted: bool,
) -> PolarsResult<GroupsType> { ... }
}Available on crate feature
algorithm_group_by only.Expand description
Used to create the tuples for a group_by operation.
Provided Methods
Sourcefn group_tuples(
&self,
_multithreaded: bool,
_sorted: bool,
) -> PolarsResult<GroupsType>
fn group_tuples( &self, _multithreaded: bool, _sorted: bool, ) -> PolarsResult<GroupsType>
Create the tuples need for a group_by operation. * The first value in the tuple is the first index of the group. * The second value in the tuple is the indexes of the groups including the first value.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl IntoGroupsType for ArrayChunked
Available on crate feature
dtype-array only.impl IntoGroupsType for BinaryChunked
impl IntoGroupsType for BinaryOffsetChunked
impl IntoGroupsType for BooleanChunked
impl IntoGroupsType for ListChunked
impl IntoGroupsType for StringChunked
impl<T> IntoGroupsType for ChunkedArray<T>where
T: PolarsNumericType,
T::Native: TotalHash + TotalEq + DirtyHash + ToTotalOrd,
<T::Native as ToTotalOrd>::TotalOrdItem: Send + Sync + Copy + Hash + Eq + DirtyHash,
impl<T> IntoGroupsType for ObjectChunked<T>where
T: PolarsObject,
Available on crate feature
object only.