get_numeric_upcast_supertype_lossless

Function get_numeric_upcast_supertype_lossless 

pub fn get_numeric_upcast_supertype_lossless(
    l: &DataType,
    r: &DataType,
) -> Option<DataType>
Returns the smallest numeric dtype that l and r can both be casted to without loss of data. If no such dtype exists, or l and r are already matching, returns None.