pub fn try_get_supertype(l: &DataType, r: &DataType) -> PolarsResult<DataType>Expand description
Given two data types, determine the data type that both types can safely be cast to.
Returns a PolarsError::ComputeError if no such data type exists.
pub fn try_get_supertype(l: &DataType, r: &DataType) -> PolarsResult<DataType>Given two data types, determine the data type that both types can safely be cast to.
Returns a PolarsError::ComputeError if no such data type exists.