pub type BooleanChunked = ChunkedArray<BooleanType>;Aliased Type
pub struct BooleanChunked { /* private fields */ }Implementations
Sourceimpl BooleanChunked
Booleans are cast to 1 or 0.
impl BooleanChunked
Booleans are cast to 1 or 0.
Sourceimpl BooleanChunked
impl BooleanChunked
pub fn num_trues(&self) -> usize
pub fn num_falses(&self) -> usize
pub fn first_true_idx(&self) -> Option<usize>
pub fn first_false_idx(&self) -> Option<usize>
Sourceimpl BooleanChunked
impl BooleanChunked
Sourcepub fn any(&self) -> bool
pub fn any(&self) -> bool
Returns whether any of the values in the column are true.
Null values are ignored.
Sourcepub fn all(&self) -> bool
pub fn all(&self) -> bool
Returns whether all values in the array are true.
Null values are ignored.
Sourcepub fn any_kleene(&self) -> Option<bool>
pub fn any_kleene(&self) -> Option<bool>
Returns whether any of the values in the column are true.
The output is unknown (None) if the array contains any null values and
no true values.
Sourcepub fn all_kleene(&self) -> Option<bool>
pub fn all_kleene(&self) -> Option<bool>
Returns whether all values in the column are true.
The output is unknown (None) if the array contains any null values and
no false values.
Sourceimpl BooleanChunked
impl BooleanChunked
Sourcepub unsafe fn mmap_slice(
name: PlSmallStr,
values: &[u8],
offset: usize,
len: usize,
) -> Self
pub unsafe fn mmap_slice( name: PlSmallStr, values: &[u8], offset: usize, len: usize, ) -> Self
Create a temporary ChunkedArray from a slice.
Safety
The lifetime will be bound to the lifetime of the slice. This will not be checked by the borrowchecker.
pub fn from_bitmap(name: PlSmallStr, bitmap: Bitmap) -> Self
Sourceimpl BooleanChunked
impl BooleanChunked
Sourcepub fn rand_bernoulli(
name: PlSmallStr,
length: usize,
p: f64,
) -> PolarsResult<Self>
Available on crate feature random only.
pub fn rand_bernoulli( name: PlSmallStr, length: usize, p: f64, ) -> PolarsResult<Self>
random only.Create ChunkedArray with samples from a Bernoulli distribution.
Sourceimpl BooleanChunked
impl BooleanChunked
Sourcepub unsafe fn agg_any(
&self,
groups: &GroupsType,
ignore_nulls: bool,
) -> BooleanChunked
Available on crate feature algorithm_group_by only.
pub unsafe fn agg_any( &self, groups: &GroupsType, ignore_nulls: bool, ) -> BooleanChunked
algorithm_group_by only.Safety
Groups should be in correct.
Sourcepub unsafe fn agg_all(
&self,
groups: &GroupsType,
ignore_nulls: bool,
) -> BooleanChunked
Available on crate feature algorithm_group_by only.
pub unsafe fn agg_all( &self, groups: &GroupsType, ignore_nulls: bool, ) -> BooleanChunked
algorithm_group_by only.Safety
Groups should be in correct.