pub struct AsyncRuntime { /* private fields */ }Implementations
Sourceimpl AsyncRuntime
impl AsyncRuntime
Sourcepub fn block_in_place_on<F>(&self, future: F) -> F::Outputwhere
F: Future,
pub fn block_in_place_on<F>(&self, future: F) -> F::Outputwhere
F: Future,
Forcibly blocks this thread to evaluate the given future. This can be dangerous and lead to deadlocks if called re-entrantly on an async worker thread as the entire thread pool can end up blocking, leading to a deadlock. If you want to prevent this use block_on, which will panic if called from an async thread.
Sourcepub fn block_on<F>(&self, future: F) -> F::Outputwhere
F: Future,
pub fn block_on<F>(&self, future: F) -> F::Outputwhere
F: Future,
Blocks this thread to evaluate the given future. Panics if the current thread is an async runtime worker thread.
Sourcepub fn spawn<F>(&self, future: F) -> JoinHandle<F::Output>
pub fn spawn<F>(&self, future: F) -> JoinHandle<F::Output>
Spawns a future onto the Tokio runtime (see [tokio::runtime::Runtime::spawn]).
pub fn spawn_blocking<F, R>(&self, f: F) -> JoinHandle<R>