pub fn par_iter_bounded<T: Sync>(items: &[T]) -> MinLen<Iter<'_, T>>Expand description
Iterate items in parallel with the number of rayon tasks bounded by the thread count.
Use this when the length of items grows with the data. A worker adds a stack frame per
stolen job, so an unbounded number of tasks can overflow a worker stack.